@@ -1,6 +1,6 @@
 /*
 
-  $Id: cfgreader.c,v 1.62 2005/07/24 18:58:13 pkot Exp $
+  $Id: cfgreader.c,v 1.65 2006/02/26 16:14:59 pkot Exp $
 
   G N O K I I
 
@@ -170,7 +170,7 @@ struct gn_cfg_header *cfg_memory_read(const char **lines)
 		}
 
 			/* Line not part of any heading */
-		fprintf(stderr, "Orphaned line: %s\n", line);
+		fprintf(stderr, _("Orphaned line: %s\n"), line);
 
 		free(buf);
 	}
@@ -492,6 +492,15 @@ static bool cfg_psection_load(gn_config *cfg, const char *section, const gn_conf
 		return false;
 	}
 
+	/* There is no global setting. You need to set irda_string
+	 * in each section if you want it working */
+	if (!(val = gn_cfg_get(gn_cfg_info, section, "irda_string")))
+		strcpy(cfg->irda_string, "");
+	else {
+		snprintf(cfg->irda_string, sizeof(cfg->irda_string), "%s", val);
+		dprintf("Setting irda_string in section %s to %s\n", section, cfg->irda_string);
+	}
+
 	return true;
 }
 
@@ -600,13 +609,14 @@ static int cfg_file_or_memory_read(const char *file, const char **lines)
 	gn_config_default.hardware_handshake = false;
 	gn_config_default.require_dcd = false;
 	gn_config_default.smsc_timeout = -1;
+	strcpy(gn_config_default.irda_string, "");
 	strcpy(gn_config_default.connect_script, "");
 	strcpy(gn_config_default.disconnect_script, "");
 	gn_config_default.rfcomm_cn = 1;
 	gn_config_default.sm_retry = 0;
 
 	if (!cfg_psection_load(&gn_config_global, "global", &gn_config_default)) {
-		fprintf(stderr, _("No global section in %s config file.\n"), file);
+		fprintf(stderr, _("No [global] section in %s config file.\n"), file);
 		return -2;
 	}
 
