@@ -1,6 +1,6 @@
 /*
 
-  $Id: misc.c,v 1.97 2005/07/18 20:55:36 bozo Exp $
+  $Id: misc.c,v 1.105 2005/11/24 00:27:16 bozo Exp $
 
   G N O K I I
 
@@ -129,12 +129,14 @@ static gn_phone_model models[] = {
 	{"2285",  "RH-3", 0 },
 	{"2300",  "RM-4", 0 },
 	{"2300b", "RM-5", 0 },
-	{"3100",  "RH-19", 0 },
-	{"3100b", "RH-50", 0 },
+	{"3100",  "RH-19", PM_CALENDAR | PM_SPEEDDIAL | PM_EXTPBK | PM_SMS | PM_FOLDERS },
+	{"3100b", "RH-50", PM_CALENDAR | PM_SPEEDDIAL | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"3105",  "RH-48", 0 },
 	{"3108",  "RH-6", 0 },
 	{"3110",  "NHE-8", PM_SMS | PM_DTMF | PM_DATA },
 	{"3110",  "0310" , PM_SMS | PM_DTMF | PM_DATA }, /* NHE-8 */
+	{"3120",  "RH-19", PM_CALENDAR | PM_SPEEDDIAL | PM_EXTPBK | PM_SMS | PM_FOLDERS },
+	{"3120b", "RH-50", PM_CALENDAR | PM_SPEEDDIAL | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"3200",  "RH-30", 0 },
 	{"3200b", "RH-31", 0 },
 	{"3210",  "NSE-8", PM_SMS | PM_DTMF | PM_KEYBOARD },
@@ -183,6 +185,7 @@ static gn_phone_model models[] = {
 	{"5125",  "NSC-1", PM_KEYBOARD },
 	{"5130",  "NSK-1", PM_NETMONITOR | PM_KEYBOARD | PM_SMS | PM_DTMF | PM_DATA | PM_SPEEDDIAL | PM_AUTHENTICATION },
 	{"5140",  "NPL-5", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_EXTPBK | PM_SMS | PM_FOLDERS },
+	{"5140i", "RM-104", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"5160",  "NSW-1", PM_NETMONITOR | PM_KEYBOARD | PM_SMS | PM_DTMF | PM_DATA | PM_SPEEDDIAL | PM_AUTHENTICATION },
 	{"5170",  "NSD-1F", 0 },
 	{"5180",  "NSD-1G", 0 },
@@ -193,6 +196,7 @@ static gn_phone_model models[] = {
 	{"6010",  "NPM-10", 0 },
 	{"6010",  "NPM-10X", 0 },
 	{"6011",  "RTE-2RH", 0 },
+	{"6015i", "RH-55", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_NETMONITOR | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"6020",  "RM-30", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_NETMONITOR | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"6021",  "RM-94", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_NETMONITOR | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"6050",  "NME-1", 0 },
@@ -217,7 +221,7 @@ static gn_phone_model models[] = {
 	{"6190",  "NSB-3", PM_CALLERGROUP | PM_CALENDAR | PM_NETMONITOR | PM_KEYBOARD | PM_SMS | PM_DTMF | PM_DATA | PM_SPEEDDIAL | PM_AUTHENTICATION },
 	{"6200",  "NPL-3", 0 },
 	{"6210",  "NPE-3", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_NETMONITOR | PM_EXTPBK | PM_SMS | PM_FOLDERS },
-	{"6220",  "RH-20", 0 },
+	{"6220",  "RH-20", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_NETMONITOR | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"6225",  "RH-27", 0 },
 	{"6230",  "RH-12_28_-", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_NETMONITOR | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"6230",  "RH12_28_-", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_NETMONITOR | PM_EXTPBK | PM_SMS | PM_FOLDERS },
@@ -230,7 +234,7 @@ static gn_phone_model models[] = {
 	{"6360",  "NPW-2", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"6370",  "NHP-2FX", 0 },
 	{"6385",  "NHP-2AX", 0 },
-	{"6500",  "NHM-7", 0 },
+	{"6500",  "NHM-7", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_NETMONITOR | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"6510",  "NPM-9", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"6560",  "RH-25", 0 },
 	{"6585",  "RH-34", 0 },
@@ -240,6 +244,7 @@ static gn_phone_model models[] = {
 	{"6610",  "NHL-4U", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"6610i", "RM-37", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"6650",  "NHM-1", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_EXTPBK | PM_SMS | PM_FOLDERS },
+	{"6680",  "RM-36", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_NETMONITOR | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"6800",  "NHL-6", 0 },
 	{"6800",  "NSB-9", 0 },
 	{"6810",  "RM-2", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_EXTPBK | PM_SMS | PM_FOLDERS },
