@@ -1,6 +1,6 @@
 /*
 
-  $Id: atgen.c,v 1.113 2005/06/29 20:55:18 pkot Exp $
+  $Id: atgen.c,v 1.118 2006/02/13 20:39:11 bozo Exp $
 
   G N O K I I
 
@@ -70,6 +70,7 @@ static gn_error ReplyGetCharset(int messagetype, unsigned char *buffer, int leng
 static gn_error ReplyGetSMSCenter(int messagetype, unsigned char *buffer, int length, gn_data *data, struct gn_statemachine *state);
 static gn_error ReplyGetSecurityCodeStatus(int messagetype, unsigned char *buffer, int length, gn_data *data, struct gn_statemachine *state);
 static gn_error ReplyGetNetworkInfo(int messagetype, unsigned char *buffer, int length, gn_data *data, struct gn_statemachine *state);
+static gn_error ReplyRing(int messagetype, unsigned char *buffer, int length, gn_data *data, struct gn_statemachine *state);
 
 static gn_error AT_Identify(gn_data *data, struct gn_statemachine *state);
 static gn_error AT_GetModel(gn_data *data, struct gn_statemachine *state);
@@ -100,6 +101,7 @@ static gn_error AT_DialVoice(gn_data *data, struct gn_statemachine *state);
 static gn_error AT_GetNetworkInfo(gn_data *data, struct gn_statemachine *state);
 static gn_error AT_AnswerCall(gn_data *data, struct gn_statemachine *state);
 static gn_error AT_CancelCall(gn_data *data, struct gn_statemachine *state);
+static gn_error AT_SetCallNotification(gn_data *data, struct gn_statemachine *state);
 
 typedef struct {
 	int gop;
@@ -140,6 +142,8 @@ static at_function_init_type at_function_init[] = {
 	{ GN_OP_MakeCall,              AT_DialVoice,             Reply },
 	{ GN_OP_AnswerCall,            AT_AnswerCall,            Reply },
 	{ GN_OP_CancelCall,            AT_CancelCall,            Reply },
+	{ GN_OP_AT_Ring,               NULL,                     ReplyRing },
+	{ GN_OP_SetCallNotification,   AT_SetCallNotification,   Reply },
 	{ GN_OP_GetNetworkInfo,        AT_GetNetworkInfo,        ReplyGetNetworkInfo },
 };
 
@@ -171,11 +175,12 @@ static char *strip_brackets(char *s)
 
 static void reply_simpletext(char *l1, char *l2, char *c, char *t)
 {
-	int i;
+	int i, n;
 
-	if ((strncmp(l1, c, 5) == 0) && (t != NULL)) {
-		if (strncmp(l2, c, 7) == 0)  {
-			for (i = 7; isspace(l2[i]); i++) ;
+	n = strlen(c);
+	if ((strncmp(l1, c, n - 2) == 0) && (t != NULL)) {
+		if (strncmp(l2, c, n) == 0)  {
+			for (i = n; isspace(l2[i]); i++) ;
 			strcpy(t, strip_quotes(l2 + i));
 		} else {
 			for (i = 0; isspace(l2[i]); i++) ;
@@ -221,6 +226,8 @@ char *memorynames[] = {
 	"CB", /* Currently selected memory */
 };
 
+#define NR_MEMORIES (sizeof (memorynames) / sizeof ((memorynames)[0]))
+
 typedef struct {
 	char *str;
 	at_charset charset;
@@ -508,6 +515,8 @@ gn_error at_memory_type_set(gn_memory_type mt, struct gn_statemachine *state)
 	gn_error ret = GN_ERR_NONE;
 
 	if (mt != drvinst->memorytype) {
+		if (mt >= NR_MEMORIES)
+			return GN_ERR_INVALIDMEMORYTYPE;
 		sprintf(req, "AT+CPBS=\"%s\"\r", memorynames[mt]);
 		ret = sm_message_send(13, GN_OP_Init, req, state);
 		if (ret)
@@ -663,30 +672,70 @@ static gn_error AT_Identify(gn_data *data, struct gn_statemachine *state)
 
 static gn_error AT_GetModel(gn_data *data, struct gn_statemachine *state)
 {
+	gn_error err;
+
 	if (sm_message_send(8, GN_OP_Identify, "AT+CGMM\r", state))
 		return GN_ERR_NOTREADY;
-	return sm_block_no_retry(GN_OP_Identify, data, state);
+	if ((err=sm_block_no_retry(GN_OP_Identify, data, state)) == GN_ERR_NONE)
+		return GN_ERR_NONE;
+
+	if (sm_message_send(7, GN_OP_Identify, "AT+GMM\r", state))
+		return GN_ERR_NOTREADY;
+	if (sm_block_no_retry(GN_OP_Identify, data, state) == GN_ERR_NONE)
+		return GN_ERR_NONE;
+
+	return err;
 }
 
 static gn_error AT_GetManufacturer(gn_data *data, struct gn_statemachine *state)
 {
+	gn_error err;
+
 	if (sm_message_send(8, GN_OP_Identify, "AT+CGMI\r", state))
 		return GN_ERR_NOTREADY;
-	return sm_block_no_retry(GN_OP_Identify, data, state);
+	if ((err = sm_block_no_retry(GN_OP_Identify, data, state)) == GN_ERR_NONE)
+		return GN_ERR_NONE;
+
+	if (sm_message_send(7, GN_OP_Identify, "AT+GMI\r", state))
+		return GN_ERR_NOTREADY;
+	if (sm_block_no_retry(GN_OP_Identify, data, state) == GN_ERR_NONE)
+		return GN_ERR_NONE;
+
+	return err;
 }
 
 static gn_error AT_GetRevision(gn_data *data, struct gn_statemachine *state)
 {
+	gn_error err;
+
 	if (sm_message_send(8, GN_OP_Identify, "AT+CGMR\r", state))
 		return GN_ERR_NOTREADY;
-	return sm_block_no_retry(GN_OP_Identify, data, state);
+	if ((err = sm_block_no_retry(GN_OP_Identify, data, state)) == GN_ERR_NONE)
+		return GN_ERR_NONE;
+
+	if (sm_message_send(7, GN_OP_Identify, "AT+GMR\r", state))
+		return GN_ERR_NOTREADY;
+	if (sm_block_no_retry(GN_OP_Identify, data, state) == GN_ERR_NONE)
+		return GN_ERR_NONE;
+
+	return err;
 }
 
 static gn_error AT_GetIMEI(gn_data *data, struct gn_statemachine *state)
 {
+	gn_error err;
+
 	if (sm_message_send(8, GN_OP_Identify, "AT+CGSN\r", state))
 		return GN_ERR_NOTREADY;
-	return sm_block_no_retry(GN_OP_Identify, data, state);
+	if ((err = sm_block_no_retry(GN_OP_Identify, data, state)) == GN_ERR_NONE)
+		return GN_ERR_NONE;
+
+	if (sm_message_send(7, GN_OP_Identify, "AT+GSN\r", state))
+		return GN_ERR_NOTREADY;
+	if (sm_block_no_retry(GN_OP_Identify, data, state) == GN_ERR_NONE)
+		return GN_ERR_NONE;
+
+	return err;
 }
 
 /* gets battery level and power source */
@@ -1049,6 +1098,26 @@ static gn_error AT_CancelCall(gn_data *data, struct gn_statemachine *state)
 	return sm_block_no_retry(GN_OP_CancelCall, data, state);
 }
 
+static gn_error AT_SetCallNotification(gn_data *data, struct gn_statemachine *state)
+{
+	at_driver_instance *drvinst = AT_DRVINST(state);
+	gn_error err;
+
+	if (!drvinst->call_notification && !data->call_notification)
+		return GN_ERR_NONE;
+
+	if (!drvinst->call_notification) {
+		if (sm_message_send(9, GN_OP_SetCallNotification, "AT+CRC=1\r", state))
+			return GN_ERR_NOTREADY;
+		if ((err = sm_block_no_retry(GN_OP_SetCallNotification, data, state)) != GN_ERR_NONE)
+			return err;
+	}
+
+	drvinst->call_notification = data->call_notification;
+
+	return GN_ERR_NONE;
+}
+
 static gn_error AT_GetNetworkInfo(gn_data *data, struct gn_statemachine *state)
 {
 	gn_error error;
@@ -1317,6 +1386,11 @@ static gn_error ReplyIdentify(int messagetype, unsigned char *buffer, int length
 		reply_simpletext(buf.line1+2, buf.line2, "+CGMM: ", data->model);
 		reply_simpletext(buf.line1+2, buf.line2, "+CGMI: ", data->manufacturer);
 		reply_simpletext(buf.line1+2, buf.line2, "+CGMR: ", data->revision);
+	} else if (!strncmp(buf.line1, "AT+G", 4)) {
+		reply_simpletext(buf.line1+2, buf.line2, "+GSN: ", data->imei);
+		reply_simpletext(buf.line1+2, buf.line2, "+GMM: ", data->model);
+		reply_simpletext(buf.line1+2, buf.line2, "+GMI: ", data->manufacturer);
+		reply_simpletext(buf.line1+2, buf.line2, "+GMR: ", data->revision);
 	}
 	return GN_ERR_NONE;
 }
@@ -1362,7 +1436,7 @@ static gn_error ReplyGetSMSStatus(int messagetype, unsigned char *buffer, int le
 	data->sms_status->folders_count = 0;
 
 	data->sms_status->new_message_store = GN_MT_ME;
-	for (i = 0; i < sizeof(memorynames)/sizeof(char *); i++) {
+	for (i = 0; i < NR_MEMORIES; i++) {
 		if (strcmp(store, memorynames[i]) == 0) {
 			data->sms_status->new_message_store = i;
 			break;
@@ -1553,6 +1627,55 @@ static gn_error ReplyGetSecurityCodeStatus(int messagetype, unsigned char *buffe
 	return GN_ERR_NONE;
 }
 
+static gn_error ReplyRing(int messagetype, unsigned char *buffer, int length, gn_data *data, struct gn_statemachine *state)
+{
+	at_driver_instance *drvinst = AT_DRVINST(state);
+	at_line_buffer buf;
+	char *pos;
+	gn_call_info cinfo;
+
+	if (!drvinst->call_notification) return GN_ERR_UNSOLICITED;
+
+	buf.line1 = buffer;
+	buf.length= length;
+	splitlines(&buf);
+
+	memset(&cinfo, 0, sizeof(cinfo));
+	cinfo.call_id = 1;
+
+	if (!strncmp(buf.line1, "RING", 4))
+		return GN_ERR_INTERNALERROR; /* AT+CRC=1 disables RING */
+
+	else if (!strncmp(buf.line1, "+CRING: ", 8)) {
+		pos = buf.line1 + 8;
+		if (!strncmp(pos, "VOICE", 5))
+			cinfo.type = GN_CALL_Voice;
+		else
+			return GN_ERR_UNHANDLEDFRAME;
+
+		drvinst->call_notification(GN_CALL_Incoming, &cinfo, state);
+
+	} else if (!strncmp(buf.line1, "CONNECT", 7))
+		drvinst->call_notification(GN_CALL_Established, &cinfo, state);
+
+	else if (!strncmp(buf.line1, "BUSY", 4))
+		drvinst->call_notification(GN_CALL_RemoteHangup, &cinfo, state);
+
+	else if (!strncmp(buf.line1, "NO ANSWER", 9))
+		drvinst->call_notification(GN_CALL_RemoteHangup, &cinfo, state);
+
+	else if (!strncmp(buf.line1, "NO CARRIER", 10))
+		drvinst->call_notification(GN_CALL_RemoteHangup, &cinfo, state);
+
+	else if (!strncmp(buf.line1, "NO DIALTONE", 11))
+		drvinst->call_notification(GN_CALL_LocalHangup, &cinfo, state);
+
+	else
+		return GN_ERR_UNHANDLEDFRAME;
+
+	return GN_ERR_UNSOLICITED;
+}
+
 static gn_error ReplyGetNetworkInfo(int messagetype, unsigned char *buffer, int length, gn_data *data, struct gn_statemachine *state)
 {
 	at_driver_instance *drvinst = AT_DRVINST(state);
@@ -1670,8 +1793,8 @@ static gn_error Initialise(gn_data *setupdata, struct gn_statemachine *state)
 	at_driver_instance *drvinst;
 	gn_data data;
 	gn_error ret = GN_ERR_NONE;
-	char model[20];
-	char manufacturer[20];
+	char model[64];
+	char manufacturer[64];
 	int i;
 
 	dprintf("Initializing AT capable mobile phone ...\n");
@@ -1692,6 +1815,7 @@ static gn_error Initialise(gn_data *setupdata, struct gn_statemachine *state)
 	drvinst->defaultcharset = AT_CHAR_UNKNOWN;
 	drvinst->charset = AT_CHAR_UNKNOWN;
 	drvinst->no_smsc = 0;
+	drvinst->call_notification = NULL;
 
 	drvinst->if_pos = 0;
 	for (i = 0; i < GN_OP_AT_Max; i++) {
