@@ -1,6 +1,6 @@
 /*
 
-  $Id: vcal.c,v 1.6 2005/05/19 22:02:48 pkot Exp $
+  $Id: vcal.c,v 1.10 2006/03/11 15:30:46 pkot Exp $
 
   G N O K I I
 
@@ -74,9 +74,9 @@ static inline const char *get_prodid()
 API int gn_calnote2ical(FILE *f, gn_calnote *calnote)
 {
 #ifdef HAVE_LIBICAL
-#  define MAX_PROP_INDEX 4
+#  define MAX_PROP_INDEX 5
 	icalcomponent *pIcal = NULL;
-	struct icaltimetype atime = {0};
+	struct icaltimetype stime = {0}, etime = {0}, atime = {0};
 	icalproperty *properties[MAX_PROP_INDEX+1] = {0}; /* order and number of properties vary */
 	int iprop = 0;
 	char compuid[64];
@@ -85,17 +85,44 @@ API int gn_calnote2ical(FILE *f, gn_calnote *calnote)
 	   birth, in this case year == 0xffff, so we set it to the arbitrary
 	   value of 1800 */
 
-	atime.year = (calnote->time.year == 0xffff ? 1800 : calnote->time.year);
-	atime.month = calnote->time.month;
-	atime.day = calnote->time.day;
-	atime.hour = calnote->time.hour;
-	atime.minute = calnote->time.minute;
-	atime.second = calnote->time.second;
+	stime.year = (calnote->time.year == 0xffff ? 1800 : calnote->time.year);
+	stime.month = calnote->time.month;
+	stime.day = calnote->time.day;
+	stime.hour = calnote->time.hour;
+	stime.minute = calnote->time.minute;
+	stime.second = calnote->time.second;
 
-	atime.is_daylight = 1;
+	stime.is_daylight = 1;
+
+	if (calnote->end_time.year) {
+		etime.year = (calnote->end_time.year == 0xffff ? 1800 : calnote->end_time.year);
+		etime.month = calnote->end_time.month;
+		etime.day = calnote->end_time.day;
+		etime.hour = calnote->end_time.hour;
+		etime.minute = calnote->end_time.minute;
+		etime.second = calnote->end_time.second;
+		etime.is_daylight = 1;
+
+		properties[iprop++] = icalproperty_new_dtend(etime);
+	}
+
+	/* FIXME: how to set alarm?
+	if (calnote->alarm.enabled) {
+		atime.year = (calnote->alarm.timestamp.year == 0xffff ? 1800 : calnote->alarm.timestamp.year);
+		atime.month = calnote->alarm.timestamp.month;
+		atime.day = calnote->alarm.timestamp.day;
+		atime.hour = calnote->alarm.timestamp.hour;
+		atime.minute = calnote->alarm.timestamp.minute;
+		atime.second = calnote->alarm.timestamp.second;
+		atime.is_daylight = 1;
+
+		properties[iprop++] = icalproperty_new_FIXME(atime);
+	}
+	*/
 
 	/* TODO: should the strings be configurable? */
 	switch(calnote->type) {
+	case GN_CALNOTE_MEMO:
 	case GN_CALNOTE_REMINDER:
 		properties[iprop++] = icalproperty_new_categories("MISCELLANEOUS");
 		properties[iprop++] = icalproperty_new_summary(calnote->text);
@@ -108,16 +135,18 @@ API int gn_calnote2ical(FILE *f, gn_calnote *calnote)
 	case GN_CALNOTE_MEETING:
 		properties[iprop++] = icalproperty_new_categories("MEETING");
 		properties[iprop++] = icalproperty_new_summary(calnote->text);
+		if (calnote->mlocation[0])
+			properties[iprop++] = icalproperty_new_location(calnote->mlocation);
 		break;
 	case GN_CALNOTE_BIRTHDAY:
 		properties[iprop++] = icalproperty_new_categories("ANNIVERSARY");
 		properties[iprop++] = icalproperty_new_summary(calnote->text);
 		do {
 			char rrule[64];
-			sprintf(rrule, "FREQ=YEARLY;INTERVAL=1;BYMONTH=%d", atime.month);
+			sprintf(rrule, "FREQ=YEARLY;INTERVAL=1;BYMONTH=%d", stime.month);
 			properties[iprop++] = icalproperty_new_rrule(icalrecurrencetype_from_string(rrule));
 		} while (0);
-		atime.is_date = 1;
+		stime.is_date = 1;
 		calnote->recurrence = GN_CALNOTE_YEARLY;
 		break;
 	default:
@@ -132,13 +161,14 @@ API int gn_calnote2ical(FILE *f, gn_calnote *calnote)
 				    icalproperty_new_version("2.0"),
 				    icalproperty_new_prodid(get_prodid()),
 				    icalcomponent_vanew(ICAL_VEVENT_COMPONENT,
-							icalproperty_new_dtstart(atime),
+							icalproperty_new_dtstart(stime),
 							icalproperty_new_uid(compuid),
 							icalproperty_new_categories("GNOKII"),
 							properties[0],
 							properties[1],
 							properties[2],
 							properties[3],
+							properties[4],
 							0),
 				    0);
 
@@ -166,62 +196,70 @@ API int gn_calnote2ical(FILE *f, gn_calnote *calnote)
 	}
 	return GN_ERR_NONE;
 #else
-	fprintf(f, "BEGIN:VCALENDAR\r\n"); 	 
-	fprintf(f, "VERSION:1.0\r\n"); 	 
-	fprintf(f, "BEGIN:VEVENT\r\n"); 	 
-	fprintf(f, "CATEGORIES:"); 	 
-	switch (calnote->type) { 	 
-	case GN_CALNOTE_REMINDER: 	 
-		fprintf(f, "MISCELLANEOUS\r\n"); 	 
-		break; 	 
-	case GN_CALNOTE_CALL: 	 
-		fprintf(f, "PHONE CALL\r\n"); 	 
-		fprintf(f, "SUMMARY:%s\r\n", calnote->phone_number); 	 
-		fprintf(f, "DESCRIPTION:%s\r\n", calnote->text); 	 
-		break; 	 
-	case GN_CALNOTE_MEETING: 	 
-		fprintf(f, "MEETING\r\n"); 	 
-		break; 	 
-	case GN_CALNOTE_BIRTHDAY: 	 
-		fprintf(f, "SPECIAL OCCASION\r\n"); 	 
-		break; 	 
-	default: 	 
-		fprintf(f, "UNKNOWN\r\n"); 	 
-		break; 	
-	} 	 
+	fprintf(f, "BEGIN:VCALENDAR\r\n");
+	fprintf(f, "VERSION:1.0\r\n");
+	fprintf(f, "BEGIN:VEVENT\r\n");
+	fprintf(f, "CATEGORIES:");
+	switch (calnote->type) {
+	case GN_CALNOTE_MEMO:
+	case GN_CALNOTE_REMINDER:
+		fprintf(f, "MISCELLANEOUS\r\n");
+		break;
+	case GN_CALNOTE_CALL: 
+		fprintf(f, "PHONE CALL\r\n");
+		fprintf(f, "SUMMARY:%s\r\n", calnote->phone_number);
+		fprintf(f, "DESCRIPTION:%s\r\n", calnote->text);
+		break; 
+	case GN_CALNOTE_MEETING: 
+		fprintf(f, "MEETING\r\n"); 
+		if (calnote->mlocation[0])
+			fprintf(f, "LOCATION:%s\r\n", calnote->mlocation);
+		break; 
+	case GN_CALNOTE_BIRTHDAY: 
+		fprintf(f, "SPECIAL OCCASION\r\n"); 
+		break; 
+	default: 
+		fprintf(f, "UNKNOWN\r\n"); 
+		break; 
+	} 
 	if (calnote->type != GN_CALNOTE_CALL)
-		fprintf(f, "SUMMARY:%s\r\n", calnote->text); 	 
-	fprintf(f, "DTSTART:%04d%02d%02dT%02d%02d%02d\r\n", calnote->time.year, 	 
-		calnote->time.month, calnote->time.day, calnote->time.hour, 	 
-		calnote->time.minute, calnote->time.second); 	 
-	if (calnote->alarm.enabled) { 	 
-		fprintf(f, "AALARM:%04d%02d%02dT%02d%02d%02d\r\n", calnote->alarm.timestamp.year, 	 
-		calnote->alarm.timestamp.month, calnote->alarm.timestamp.day, calnote->alarm.timestamp.hour, 	 
-		calnote->alarm.timestamp.minute, calnote->alarm.timestamp.second); 	 
-	} 	 
-	switch (calnote->recurrence) { 	 
-	case GN_CALNOTE_NEVER: 	 
-		break; 	 
-	case GN_CALNOTE_DAILY: 	 
-		fprintf(f, "RRULE:FREQ=DAILY\r\n"); 	 
-		break; 	 
-	case GN_CALNOTE_WEEKLY: 	 
-		fprintf(f, "RRULE:FREQ=WEEKLY\r\n"); 	 
-		break; 	 
-	case GN_CALNOTE_2WEEKLY: 	 
-		fprintf(f, "RRULE:FREQ=WEEKLY;INTERVAL=2\r\n"); 	 
-		break; 	
-	case GN_CALNOTE_MONTHLY: 	 
-		fprintf(f, "RRULE:FREQ=MONTHLY\r\n"); 	 
-		break; 	 
-	case GN_CALNOTE_YEARLY: 	 
-		fprintf(f, "RRULE:FREQ=YEARLY\r\n"); 	 
-		break; 	
-	default: 	 
-		fprintf(f, "RRULE:FREQ=HOURLY;INTERVAL=%d\r\n", calnote->recurrence); 	 
-		break; 	 
-	} 	 
-	fprintf(f, "END:VEVENT\r\n"); 	 
+		fprintf(f, "SUMMARY:%s\r\n", calnote->text);
+	fprintf(f, "DTSTART:%04d%02d%02dT%02d%02d%02d\r\n", calnote->time.year,
+		calnote->time.month, calnote->time.day, calnote->time.hour, 
+		calnote->time.minute, calnote->time.second); 
+	if (calnote->end_time.year) {
+		fprintf(f, "DTEND:%04d%02d%02dT%02d%02d%02d\r\n", calnote->end_time.year, 
+			calnote->end_time.month, calnote->end_time.day, calnote->end_time.hour, 
+			calnote->end_time.minute, calnote->end_time.second); 
+	}
+	if (calnote->alarm.enabled) {
+		fprintf(f, "AALARM:%04d%02d%02dT%02d%02d%02d\r\n", calnote->alarm.timestamp.year, 
+		calnote->alarm.timestamp.month, calnote->alarm.timestamp.day, calnote->alarm.timestamp.hour, 
+		calnote->alarm.timestamp.minute, calnote->alarm.timestamp.second); 
+	} 
+	switch (calnote->recurrence) { 
+	case GN_CALNOTE_NEVER: 
+		break; 
+	case GN_CALNOTE_DAILY: 
+		fprintf(f, "RRULE:FREQ=DAILY\r\n"); 
+		break; 
+	case GN_CALNOTE_WEEKLY: 
+		fprintf(f, "RRULE:FREQ=WEEKLY\r\n"); 
+		break; 
+	case GN_CALNOTE_2WEEKLY: 
+		fprintf(f, "RRULE:FREQ=WEEKLY;INTERVAL=2\r\n"); 
+		break; 
+	case GN_CALNOTE_MONTHLY: 
+		fprintf(f, "RRULE:FREQ=MONTHLY\r\n"); 
+		break; 
+	case GN_CALNOTE_YEARLY: 
+		fprintf(f, "RRULE:FREQ=YEARLY\r\n"); 
+		break; 
+	default: 
+		fprintf(f, "RRULE:FREQ=HOURLY;INTERVAL=%d\r\n", calnote->recurrence); 
+		break; 
+	} 
+	fprintf(f, "END:VEVENT\r\n"); 
 	fprintf(f, "END:VCALENDAR\r\n");
 	return GN_ERR_NONE;
 #endif /* HAVE_LIBICAL */
@@ -248,7 +286,7 @@ API int gn_ical2calnote(FILE *f, gn_calnote *calnote, int id)
 #ifdef HAVE_LIBICAL
 	icalparser *parser = NULL;
 	icalcomponent *comp = NULL, *compresult = NULL;
-	struct icaltimetype dtstart = {0};
+	struct icaltimetype dtstart = {0}, dtend = {0};
 
 	parser = icalparser_new();
 	if (!parser) {
@@ -311,6 +349,21 @@ API int gn_ical2calnote(FILE *f, gn_calnote *calnote, int id)
 			}
 		}
 
+		/* end time */
+		memset(&calnote->end_time, 0, sizeof(calnote->end_time));
+		dtend = icalcomponent_get_dtend(compresult);
+		if (!icaltime_is_null_time(dtend)) {
+			calnote->end_time.year = dtend.year;
+			calnote->end_time.month = dtend.month;
+			calnote->end_time.day = dtend.day;
+			if (!icaltime_is_date(dtend)) {
+				calnote->end_time.hour = dtend.hour;
+				calnote->end_time.minute = dtend.minute;
+				calnote->end_time.second = dtend.second;
+				/* TODO: what about time zones? */
+			}
+		}
+
 		/* alarm */
 		alarm = icalcomponent_get_first_component(comp, ICAL_VALARM_COMPONENT);
 		if (alarm) {
@@ -347,6 +400,10 @@ API int gn_ical2calnote(FILE *f, gn_calnote *calnote, int id)
 			}
 		}
 
+		str = icalcomponent_get_location(compresult);
+		if (!str) str = "";
+		snprintf(calnote->mlocation, sizeof(calnote->mlocation), "%s", str);
+
 		fprintf(stderr, _("Component found\n%s\n"), icalcomponent_as_ical_string(compresult));
 
 	}
@@ -401,11 +458,11 @@ API int gn_todo2ical(FILE *f, gn_todo *ctodo)
 	return GN_ERR_NONE;
 #else
 	fprintf(f, "BEGIN:VCALENDAR\r\n");
-	fprintf(f, "VERSION:1.0\r\n"); 	 
-	fprintf(f, "BEGIN:VTODO\r\n"); 	 
-	fprintf(f, "PRIORITY:%i\r\n", ctodo->priority); 	 
-	fprintf(f, "SUMMARY:%s\r\n", ctodo->text); 	 
-	fprintf(f, "END:VTODO\r\n"); 	 
+	fprintf(f, "VERSION:1.0\r\n"); 
+	fprintf(f, "BEGIN:VTODO\r\n"); 
+	fprintf(f, "PRIORITY:%i\r\n", ctodo->priority); 
+	fprintf(f, "SUMMARY:%s\r\n", ctodo->text); 
+	fprintf(f, "END:VTODO\r\n"); 
 	fprintf(f, "END:VCALENDAR\r\n");
 	return GN_ERR_NONE;
 #endif /* HAVE_LIBICAL */
