@@ -1,6 +1,6 @@
 /*
 
-  $Id: common.h,v 1.136 2005/04/24 19:41:23 pkot Exp $
+  $Id: common.h,v 1.142 2006/02/25 23:47:47 pkot Exp $
 
   G N O K I I
 
@@ -137,10 +137,26 @@ typedef struct {
    not support these lengths so they have their own limits set. */
 #define GN_PHONEBOOK_NAME_MAX_LENGTH            61   /* For 6510 */
 #define GN_PHONEBOOK_NUMBER_MAX_LENGTH          49   /* For 6510 */
-#define GN_PHONEBOOK_SUBENTRIES_MAX_NUMBER      10   /* For 6510 */
+#define GN_PHONEBOOK_SUBENTRIES_MAX_NUMBER      64   /* it was 10 for 6510, but modern phones supports more */
 						     /* 7110 is able to have in one
 						      * entry 5 numbers and 4
-						      * texts [email,notice,postal,url] */
+						      * texts [email,notice,postal,url].
+						      * Dirk reported on gnokii-users that N70 has the following additional fields:
+						      * - Company
+						      * - Position
+						      * - Aliasname
+						      * - DTMF
+						      * - Benutzerkennung (user id?)
+						      * - all postal fields:
+						      *  - PO Box
+						      *  - Zusatz (additional?)
+						      *  - Street
+						      *  - Zip Code
+						      *  - City
+						      *  - State/Province
+						      *  - Country
+						      *  - Birthday
+						      */
 #define GN_PHONEBOOK_CALLER_GROUPS_MAX_NUMBER    5
 #define GN_PHONEBOOK_ENTRY_MAX_LENGTH 1024
 
@@ -264,6 +280,7 @@ typedef enum {
 	GN_CALNOTE_CALL     = 0x02, /* Call */
 	GN_CALNOTE_BIRTHDAY = 0x04, /* Birthday */
 	GN_CALNOTE_REMINDER = 0x08, /* Reminder */
+	GN_CALNOTE_MEMO     = 0x16, /* Memo */
 } gn_calnote_type;
 
 typedef enum {
@@ -280,7 +297,8 @@ typedef enum {
 #define GN_CALNOTE_NUMBER_MAX_LENGTH  49
 
 typedef struct {
-	int enabled; /* Is alarm set ? */
+	int enabled; /* Is alarm set? */
+	int tone; /* Is alarm tone enabled? */
 	gn_timestamp timestamp;
 } gn_calnote_alarm;
 
@@ -289,9 +307,11 @@ typedef struct {
 	int location;                                    /* The number of the note in the phone memory */
 	gn_calnote_type type;                            /* The type of the note */
 	gn_timestamp time;                               /* The time of the note */
+	gn_timestamp end_time;                           /* The end time of the note */
 	gn_calnote_alarm alarm;                          /* The alarm of the note */
 	char text[GN_CALNOTE_MAX_LENGTH];                /* The text of the note */
 	char phone_number[GN_CALNOTE_NUMBER_MAX_LENGTH]; /* For Call only: the phone number */
+	char mlocation[GN_CALNOTE_MAX_LENGTH];           /* For Meeting only: the location field */
 	gn_calnote_recurrence recurrence;                /* Recurrence of the note */
 } gn_calnote;
 
@@ -673,21 +693,21 @@ typedef enum {
 } gn_log_target;
 
 typedef struct {
-	unsigned char id[6];
-	char name[512];
-	int year;
+	unsigned char *id;	/* file id */
+	char name[512];		/* file name */
+	int year;		/* datetime of creation/modification */
 	int month;
 	int day;
 	int hour;
 	int minute;
 	int second;
-	int file_length;
-	int togo;
-	int just_sent;
-	unsigned char *file;
+	int file_length;	/* size of the file */
+	int togo;		/* amount of bytes to be sent yet */
+	int just_sent;		/* ??? */
+	unsigned char *file;	/* file contents */
 } gn_file;
 
-#define GN_FILES_MAX_COUNT 100
+#define GN_FILES_MAX_COUNT 1024
 
 typedef struct {
 	char path[512];
