@@ -1,6 +1,6 @@
 /*
 
-  $Id: xgnokii.c,v 1.79 2005/05/09 20:31:51 pkot Exp $
+  $Id: xgnokii.c,v 1.82 2006/01/15 15:13:27 dforsi Exp $
   
   X G N O K I I
 
@@ -23,7 +23,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
   Copyright (C) 1999      Pavel Jank ml., Hugh Blemings
-  Copyright (C) 1999-2002 Jn Derfik <ja@mail.upjs.sk>.
+  Copyright (C) 1999-2005 Jan Derfinak
   Copyright (C) 2001-2004 Pawel Kot
   Copyright (C) 2001      Chris Kemp, Marian Jancar
   Copyright (C) 2002      Markus Plail
@@ -31,6 +31,9 @@
 
 */
 
+#include <gdk/gdkkeysyms.h>
+#include <gtk/gtk.h>
+
 #include "config.h"
 #include "compat.h"
 #include "misc.h"
@@ -61,9 +64,6 @@
 #  undef OUT
 #endif
 
-#include <gdk/gdkkeysyms.h>
-#include <gtk/gtk.h>
-
 #include "gnokii.h"
 
 #include "xgnokii.h"
@@ -360,7 +360,7 @@ static inline void DrawSMSReceived(GtkWidget * data)
 
 static inline void DrawWorking(GtkWidget * data)
 {
-	DrawText(data, 40, _("Working ..."));
+	DrawText(data, 40, _("Working..."));
 }
 
 
@@ -406,7 +406,6 @@ static gint Update(gpointer data)
 	static gchar lastCallNum[20] = "";
 	static gchar callBuf[80];
 	static gchar timeBuf[10];
-	static gchar *anonym = "anonymous";
 	static struct tm stm;
 	static gint callTimerStart = 0;
 	gint callTimer = 0;
@@ -465,7 +464,7 @@ static gint Update(gpointer data)
 			outgoing = FALSE;
 
 			if (*phoneMonitor.call.callNum == '\0')
-				name = anonym;
+				name = _("anonymous");
 			else if (strncmp(phoneMonitor.call.callNum, lastCallNum, 20)) {
 				strncpy(lastCallNum, phoneMonitor.call.callNum, 20);
 				lastCallNum[19] = '\0';
@@ -480,7 +479,7 @@ static gint Update(gpointer data)
 		if (outgoing)
 			g_snprintf(callBuf, 80, _("Outgoing call in progress:\nTime: %s"), timeBuf);
 		else
-			g_snprintf(callBuf, 80, _("Incomming call from: %s\nTime: %s"), name,
+			g_snprintf(callBuf, 80, _("Incoming call from: %s\nTime: %s"), name,
 				   timeBuf);
 
 		gtk_label_set_text(GTK_LABEL(inCallDialog.label), callBuf);
@@ -550,7 +549,7 @@ static void ParseSMSCenters(void)
 
 		case GN_SMS_MF_Email:
 		case GN_SMS_MF_UCI:
-			row[2] = g_strdup(_("E-Mail"));
+			row[2] = g_strdup(_("Email"));
 			break;
 
 		case GN_SMS_MF_ERMES:
@@ -572,19 +571,19 @@ static void ParseSMSCenters(void)
 
 		switch (configDialogData.sms.smsSetting[i].validity) {
 		case GN_SMS_VP_1H:
-			row[3] = g_strdup(_("1 h"));
+			row[3] = g_strdup(_("1 hour"));
 			break;
 
 		case GN_SMS_VP_6H:
-			row[3] = g_strdup(_("6 h"));
+			row[3] = g_strdup(_("6 hours"));
 			break;
 
 		case GN_SMS_VP_24H:
-			row[3] = g_strdup(_("24 h"));
+			row[3] = g_strdup(_("24 hours"));
 			break;
 
 		case GN_SMS_VP_72H:
-			row[3] = g_strdup(_("72 h"));
+			row[3] = g_strdup(_("72 hours"));
 			break;
 
 		case GN_SMS_VP_1W:
@@ -592,11 +591,11 @@ static void ParseSMSCenters(void)
 			break;
 
 		case GN_SMS_VP_Max:
-			row[3] = g_strdup(_("Max. time"));
+			row[3] = g_strdup(_("Max. Time"));
 			break;
 
 		default:
-			row[3] = g_strdup(_("24 h"));
+			row[3] = g_strdup(_("24 hours"));
 			break;
 		}
 
@@ -1204,8 +1203,8 @@ static GtkWidget *CreateAboutDialog(void)
 Copyright (C) 1999-2004 Pavel Janik ml.,\nHugh Blemings, Jan Derfinak,\n\
 Pawel Kot and others\n\
 xgnokii is free software, covered by the GNU General Public License,\n\
-d you are welcome to change it and/or distribute copies of it under\n\
-certain conditions. There is absolutely no waranty for xgnokii.\n\
+and you are welcome to change it and/or distribute copies of it under\n\
+certain conditions. There is absolutely no warranty for xgnokii.\n\
 See GPL for details.\n"), XVERSION, VERSION);
 	label = gtk_label_new((gchar *) buf);
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
@@ -1292,7 +1291,7 @@ static inline gint RefreshUserStatusCallBack(GtkWidget * widget,
 					     GdkEventKey * event, gpointer callback_data)
 {
 	RefreshUserStatus();
-	if (GTK_EDITABLE(widget)->editable == FALSE)
+	if (gtk_editable_get_editable (GTK_EDITABLE(widget)) == FALSE)
 		return (FALSE);
 	if (event->keyval == GDK_BackSpace || event->keyval == GDK_Clear ||
 	    event->keyval == GDK_Insert || event->keyval == GDK_Delete ||
@@ -1436,7 +1435,7 @@ static void ShowEditSMSSetDialog(GtkWidget * w, gpointer data)
 		gtk_widget_show(item);
 		gtk_menu_append(GTK_MENU(menu), item);
 
-		item = gtk_menu_item_new_with_label(_("E-Mail"));
+		item = gtk_menu_item_new_with_label(_("Email"));
 		gtk_signal_connect(GTK_OBJECT(item), "activate",
 				   GTK_SIGNAL_FUNC(SetFormat), (gpointer) GN_SMS_MF_Email);
 		gtk_widget_show(item);
@@ -1464,25 +1463,25 @@ static void ShowEditSMSSetDialog(GtkWidget * w, gpointer data)
 		gtk_widget_show(item);
 		gtk_menu_append(GTK_MENU(menu), item);
 
-		item = gtk_menu_item_new_with_label(_("1 h"));
+		item = gtk_menu_item_new_with_label(_("1 hour"));
 		gtk_signal_connect(GTK_OBJECT(item), "activate",
 				   GTK_SIGNAL_FUNC(SetValidity), (gpointer) GN_SMS_VP_1H);
 		gtk_widget_show(item);
 		gtk_menu_append(GTK_MENU(menu), item);
 
-		item = gtk_menu_item_new_with_label(_("6 h"));
+		item = gtk_menu_item_new_with_label(_("6 hours"));
 		gtk_signal_connect(GTK_OBJECT(item), "activate",
 				   GTK_SIGNAL_FUNC(SetValidity), (gpointer) GN_SMS_VP_6H);
 		gtk_widget_show(item);
 		gtk_menu_append(GTK_MENU(menu), item);
 
-		item = gtk_menu_item_new_with_label(_("24 h"));
+		item = gtk_menu_item_new_with_label(_("24 hours"));
 		gtk_signal_connect(GTK_OBJECT(item), "activate",
 				   GTK_SIGNAL_FUNC(SetValidity), (gpointer) GN_SMS_VP_24H);
 		gtk_widget_show(item);
 		gtk_menu_append(GTK_MENU(menu), item);
 
-		item = gtk_menu_item_new_with_label(_("72 h"));
+		item = gtk_menu_item_new_with_label(_("72 hours"));
 		gtk_signal_connect(GTK_OBJECT(item), "activate",
 				   GTK_SIGNAL_FUNC(SetValidity), (gpointer) GN_SMS_VP_72H);
 		gtk_widget_show(item);
@@ -2039,7 +2038,7 @@ static GtkWidget *CreateOptionsDialog(void)
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 2);
 	gtk_widget_show(hbox);
 
-	label = gtk_label_new(_("E-Mail:"));
+	label = gtk_label_new(_("Email:"));
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);
 	gtk_widget_show(label);
 
