@@ -1,6 +1,6 @@
 /*
 
-  $Id: xgnokii_dtmf.c,v 1.12 2005/04/24 20:57:37 pkot Exp $
+  $Id: xgnokii_dtmf.c,v 1.15 2006/01/15 15:13:27 dforsi Exp $
 
   X G N O K I I
 
@@ -23,7 +23,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
   Copyright (C) 1999 Pavel Jank ml., Hugh Blemings
-  & Jn Derfik <ja@mail.upjs.sk>.
+  & 1999-2005 Jan Derfinak.
 
 */
 
@@ -92,11 +92,11 @@ static void OkLoadDialog(GtkWidget * w, GtkFileSelection * fs)
 	gchar line[MAX_DTMF_LENGTH + 1];
 	gchar buf[80];
 
-	fileName = gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
+	fileName = (gchar *) gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
 	gtk_widget_hide(GTK_WIDGET(fs));
 
 	if ((f = fopen(fileName, "r")) == NULL) {
-		g_snprintf(buf, 80, _("Can't open file %s for reading!"), fileName);
+		g_snprintf(buf, 80, _("Can't open file %s for reading!\n"), fileName);
 		gtk_label_set_text(GTK_LABEL(errorDialog.text), buf);
 		gtk_widget_show(errorDialog.dialog);
 		return;
@@ -132,7 +132,7 @@ static void SaveDTMF()
 	gchar buf[80];
 
 	if ((f = fopen(saveFileName, "w")) == NULL) {
-		g_snprintf(buf, 80, _("Can't open file %s for writing!"), saveFileName);
+		g_snprintf(buf, 80, _("Can't open file %s for writing!\n"), saveFileName);
 		gtk_label_set_text(GTK_LABEL(errorDialog.text), buf);
 		gtk_widget_show(errorDialog.dialog);
 		return;
@@ -156,15 +156,15 @@ static void OkSaveDialog(GtkWidget * w, GtkFileSelection * fs)
 	static YesNoDialog dialog = { NULL, NULL };
 	gchar err[255];
 
-	saveFileName = gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
+	saveFileName = (gchar *) gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
 	gtk_widget_hide(GTK_WIDGET(fs));
 
 	if ((f = fopen(saveFileName, "r")) != NULL) {
 		fclose(f);
 		if (dialog.dialog == NULL) {
-			CreateYesNoDialog(&dialog, YesSaveDialog, CancelDialog, GUI_DTMFWindow);
+			CreateYesNoDialog(&dialog, (GtkSignalFunc) YesSaveDialog, (GtkSignalFunc) CancelDialog, GUI_DTMFWindow);
 			gtk_window_set_title(GTK_WINDOW(dialog.dialog), _("Overwrite file?"));
-			g_snprintf(err, 255, _("File %s already exist.\nOverwrite?"), saveFileName);
+			g_snprintf(err, 255, _("File %s already exists.\nOverwrite?"), saveFileName);
 			gtk_label_set_text(GTK_LABEL(dialog.text), err);
 		}
 		gtk_widget_show(dialog.dialog);
@@ -257,7 +257,7 @@ void GUI_CreateDTMFWindow()
 
 	gtk_item_factory_create_items(item_factory, nmenu_items, menu_items, NULL);
 
-	gtk_accel_group_attach(accel_group, GTK_OBJECT(GUI_DTMFWindow));
+	gtk_window_add_accel_group(GTK_WINDOW(GUI_DTMFWindow), accel_group);
 
 	/* Finally, return the actual menu bar created by the item factory. */
 	menubar = gtk_item_factory_get_widget(item_factory, "<main>");
@@ -311,12 +311,12 @@ void GUI_CreateDTMFWindow()
 	gtk_table_attach_defaults(GTK_TABLE(table), button, 2, 3, 5, 6);
 
 
-	button = gtk_button_new_with_label("Pause");
+	button = gtk_button_new_with_label(_("Pause"));
 	gtk_signal_connect(GTK_OBJECT(button), "clicked",
 			   GTK_SIGNAL_FUNC(ButtonCB), (gpointer) 'p');
 	gtk_table_attach_defaults(GTK_TABLE(table), button, 0, 1, 6, 7);
 
-	button = gtk_button_new_with_label("Wait");
+	button = gtk_button_new_with_label(_("Wait"));
 	gtk_signal_connect(GTK_OBJECT(button), "clicked",
 			   GTK_SIGNAL_FUNC(ButtonCB), (gpointer) 'w');
 	gtk_table_attach_defaults(GTK_TABLE(table), button, 1, 2, 6, 7);
