@@ -1,6 +1,6 @@
 /*
 
-  $Id: xgnokii_logos.c,v 1.29 2005/04/24 20:57:37 pkot Exp $
+  $Id: xgnokii_logos.c,v 1.37 2006/03/07 20:37:48 pkot Exp $
    
   X G N O K I I
 
@@ -23,9 +23,9 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
   Copyright (C) 1999      Pavel Jank ml., Hugh Blemings
-  Copyright (C) 1999-2001 Jn Derfik <ja@mail.upjs.sk>.
+  Copyright (C) 1999-2005 Jan Derfinak
   Copyright (C) 2000-2001 Marcin Wiacek, Chris Kemp
-  Copyright (C) 2002-2003 Pawel Kot
+  Copyright (C) 2002-2006 Pawel Kot
   Copyright (C) 2002      Markus Plail
 
 */
@@ -36,6 +36,8 @@
 #include <signal.h>
 #include <sys/types.h>
 #include <string.h>
+#include <dirent.h>
+
 #include <gtk/gtk.h>
 
 #include "misc.h"
@@ -82,12 +84,15 @@ int drawingAreaWidth, drawingAreaHeight;	/* in pixels */
 int mouseButtonPushed = 0;
 
 /* stuff for previewArea */
+#define MAX_PIXMAPS 100
 GtkWidget *previewArea = NULL;
 GdkPixmap *previewPixmap = NULL;
 GdkPixmap *greenPixelPixmap;
 int previewPixmapWidth, previewPixmapHeight;
 int previewAvailable = 1, showPreviewErrorDialog = 1;
-int previewPixmapNumber = 0;
+int previewPixmapNumber = 0, pixmapFiles = 0;
+int pixmapsInitialized = FALSE, pixmapDefaultId = -1;
+gchar *pixmapNames[MAX_PIXMAPS];
 
 gn_bmp bitmap, oldBitmap;
 gn_network_info networkInfo;
@@ -146,94 +151,66 @@ int GetMaxFrom3(int a, int b, int c)
 	}
 }
 
-/* load preview pixmap from file */
-GdkPixmap *GetPreviewPixmap(GtkWidget * widget)
+/* Read all Preview* files from the given path and put them into pixmapNames
+ * array. We support no more than MAX_PIXMAP files. */
+static void GetPixmaps(gchar *path)
 {
-	GdkPixmap *pixmap;
+	DIR *dir;
+	struct dirent *de;
+
+	dir = opendir(path);
+	while (dir && (de = readdir(dir))) {
+		if (pixmapFiles == MAX_PIXMAPS)
+			break;
+		if (!strncmp(de->d_name, "Preview_", 8)) {
+			pixmapNames[pixmapFiles] = g_strdup(de->d_name);
+			if (!strcmp(de->d_name, "Preview_default.xpm"))
+				pixmapDefaultId = pixmapFiles;
+			pixmapFiles++;
+		}
+	}
+	pixmapsInitialized = TRUE;
+}
+
+/* Get the pixmap that filename contains model string. If there's none, get
+ * default one. */
+static int GetPixmapId(gchar *model)
+{
+	int i, pos = pixmapDefaultId;
+
+	for (i = 0; i < pixmapFiles; i++) {
+		if (strstr(pixmapNames[i], model)) {
+			pos = i;
+			break;
+		}
+	}
+	return pos;
+}
+
+/* Load preview pixmap from file. On the first run do the initialization.
+ * Next runs are after clicking on the preview area that should switch to the
+ * next pixmap. In case none is available NULL is returned. */
+GdkPixmap *GetPreviewPixmap(GtkWidget *widget)
+{
+	GdkPixmap *pixmap = NULL;
 	GdkBitmap *mask;
-	gchar *file;
+	gchar *file, *dirname;
+	struct stat *buf;
 
-	if (previewPixmapNumber == 0) {
-		if (!strcmp(xgnokiiConfig.model, "6110") || !strcmp(xgnokiiConfig.model, "6120")) {
-			file = g_strdup_printf("%s%s", xgnokiiConfig.xgnokiidir,
-					       "/xpm/Preview_6110.xpm");
-			previewPixmapNumber = 1;
-		} else if (!strcmp(xgnokiiConfig.model, "6130") ||
-			   !strcmp(xgnokiiConfig.model, "6150") ||
-			   !strcmp(xgnokiiConfig.model, "616x") ||
-			   !strcmp(xgnokiiConfig.model, "6185") ||
-			   !strcmp(xgnokiiConfig.model, "6190")) {
-			file = g_strdup_printf("%s%s", xgnokiiConfig.xgnokiidir,
-					       "/xpm/Preview_6150.xpm");
-			previewPixmapNumber = 2;
-		} else if (!strcmp(xgnokiiConfig.model, "3210")) {
-			file = g_strdup_printf("%s%s", xgnokiiConfig.xgnokiidir,
-					       "/xpm/Preview_3210.xpm");
-			previewPixmapNumber = 3;
-		} else if (!strcmp(xgnokiiConfig.model, "3310") ||
-			   !strcmp(xgnokiiConfig.model, "3330")) {
-			file = g_strdup_printf("%s%s", xgnokiiConfig.xgnokiidir,
-					       "/xpm/Preview_3310.xpm");
-			previewPixmapNumber = 4;
-		} else if (!strcmp(xgnokiiConfig.model, "5110") ||
-			   !strcmp(xgnokiiConfig.model, "5130")) {
-			file = g_strdup_printf("%s%s", xgnokiiConfig.xgnokiidir,
-					       "/xpm/Preview_5110.xpm");
-			previewPixmapNumber = 5;
-		} else if (!strcmp(xgnokiiConfig.model, "6250")) {
-			file = g_strdup_printf("%s%s", xgnokiiConfig.xgnokiidir,
-					       "/xpm/Preview_6250.xpm");
-			previewPixmapNumber = 6;
-		} else if (!strcmp(xgnokiiConfig.model, "7110")) {
-			file = g_strdup_printf("%s%s", xgnokiiConfig.xgnokiidir,
-					       "/xpm/Preview_7110.xpm");
-			previewPixmapNumber = 7;
-		} else {
-			file = g_strdup_printf("%s%s", xgnokiiConfig.xgnokiidir,
-					       "/xpm/Preview_6210.xpm");
-			previewPixmapNumber = 8;
-		}
-	} else
-		switch (previewPixmapNumber) {
-		case 1:
-			file = g_strdup_printf("%s%s", xgnokiiConfig.xgnokiidir,
-					       "/xpm/Preview_6110.xpm");
-			break;
-		case 2:
-			file = g_strdup_printf("%s%s", xgnokiiConfig.xgnokiidir,
-					       "/xpm/Preview_6150.xpm");
-			break;
-		case 3:
-			file = g_strdup_printf("%s%s", xgnokiiConfig.xgnokiidir,
-					       "/xpm/Preview_3210.xpm");
-			break;
-		case 4:
-			file = g_strdup_printf("%s%s", xgnokiiConfig.xgnokiidir,
-					       "/xpm/Preview_3310.xpm");
-			break;
-		case 5:
-			file = g_strdup_printf("%s%s", xgnokiiConfig.xgnokiidir,
-					       "/xpm/Preview_5110.xpm");
-			break;
-		case 6:
-			file = g_strdup_printf("%s%s", xgnokiiConfig.xgnokiidir,
-					       "/xpm/Preview_6250.xpm");
-			break;
-		case 7:
-			file = g_strdup_printf("%s%s", xgnokiiConfig.xgnokiidir,
-					       "/xpm/Preview_7110.xpm");
-			break;
-		default:
-			file = g_strdup_printf("%s%s", xgnokiiConfig.xgnokiidir,
-					       "/xpm/Preview_6210.xpm");
-			break;
-		}
+	dirname = g_strdup_printf("%s/xpm/", xgnokiiConfig.xgnokiidir);
+	if (!pixmapsInitialized) {
+		GetPixmaps(dirname);
+		previewPixmapNumber = GetPixmapId(xgnokiiConfig.model);
+	}
 
-	pixmap = gdk_pixmap_create_from_xpm(widget->window, &mask,
+	if (previewPixmapNumber >= 0) {
+		file = g_strdup_printf("%s%s", dirname,
+					pixmapNames[previewPixmapNumber]);
+		pixmap = gdk_pixmap_create_from_xpm(widget->window, &mask,
 					    &widget->style->bg[GTK_STATE_NORMAL], file);
-
-	g_free(file);
-
+		g_free(file);
+	}
+	g_free(dirname);
 	return pixmap;
 }
 
@@ -733,7 +710,7 @@ void UpdateToolScreen(GtkWidget * widget, int x1, int y1, int x2, int y2)
 
 gint PreviewAreaButtonPressEvent(GtkWidget * widget, GdkEventButton * event)
 {
-	previewPixmapNumber = (previewPixmapNumber % 8) + 1;
+	previewPixmapNumber = ((previewPixmapNumber + 1) % pixmapFiles);
 
 	gtk_drawing_area_size(GTK_DRAWING_AREA(previewArea),
 			      previewPixmapWidth, previewPixmapHeight);
@@ -990,7 +967,7 @@ void GetNetworkInfoEvent(GtkWidget * widget)
 
 	/* watch for errors */
 	if (error != GN_ERR_NONE) {
-		gchar *buf = g_strdup_printf(_("Error getting network info\n(error=%d)"), error);
+		gchar *buf = g_strdup_printf(_("Error getting network info\n%s"), gn_error_print(error));
 		gtk_label_set_text(GTK_LABEL(errorDialog.text), buf);
 		gtk_widget_show(errorDialog.dialog);
 		g_free(buf);
@@ -1008,8 +985,8 @@ void GetLogoEvent(GtkWidget * widget)
 	int i;
 	PhoneEvent *e = (PhoneEvent *) g_malloc(sizeof(PhoneEvent));
 	D_Bitmap *data = (D_Bitmap *) g_malloc(sizeof(D_Bitmap));
-	char *netcou = gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(networkCombo)->entry));
-	char network[64], country[24];
+	gchar *netcou = (gchar *) gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(networkCombo)->entry));
+	gchar network[64], country[24];
 
 	/* prepare data for event */
 	sscanf(netcou, "%s (%[^)])", network, country);
@@ -1034,7 +1011,7 @@ void GetLogoEvent(GtkWidget * widget)
 
 	/* watch for errors */
 	if (error != GN_ERR_NONE) {
-		gchar *buf = g_strdup_printf(_("Error getting bitmap\n(error=%d)"), error);
+		gchar *buf = g_strdup_printf(_("Error getting bitmap\n%s"), gn_error_print(error));
 		gtk_label_set_text(GTK_LABEL(errorDialog.text), buf);
 		gtk_widget_show(errorDialog.dialog);
 		g_free(buf);
@@ -1049,8 +1026,8 @@ void SetLogoEvent(GtkWidget * widget)
 	gn_error error;
 	PhoneEvent *e = (PhoneEvent *) g_malloc(sizeof(PhoneEvent));
 	D_Bitmap *data = (D_Bitmap *) g_malloc(sizeof(D_Bitmap));
-	char *netcou = gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(networkCombo)->entry));
-	char network[64], country[24];
+	gchar *netcou = (gchar *) gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(networkCombo)->entry));
+	gchar network[64], country[24];
 	int i;
 
 	/* prepare data */
@@ -1084,7 +1061,7 @@ void SetLogoEvent(GtkWidget * widget)
 
 	/* watch for errors */
 	if (error != GN_ERR_NONE) {
-		gchar *buf = g_strdup_printf(_("Error setting bitmap\n(error=%d)"), error);
+		gchar *buf = g_strdup_printf(_("Error setting bitmap\n%s"), gn_error_print(error));
 		gtk_label_set_text(GTK_LABEL(errorDialog.text), buf);
 		gtk_widget_show(errorDialog.dialog);
 		g_free(buf);
@@ -1274,8 +1251,8 @@ gint LogoTypeEvent(GtkWidget * widget)
 {
 	int clear = 0;
 	g_print("LogoTypeEvent called!\n");
-	g_print("height: %i, width: %i\n", statemachine.driver.phone.startup_logo_height,
-		statemachine.driver.phone.startup_logo_width);
+	g_print("width: %i, height: %i\n", statemachine.driver.phone.startup_logo_width,
+		statemachine.driver.phone.startup_logo_height);
 	/* is startupLogo? */
 	/* Resize and clear anyway - CK */
 	if (GTK_TOGGLE_BUTTON(buttonStartup)->active) {
@@ -1339,7 +1316,7 @@ void ExportLogoFileMain(gchar * name)
 
 	error = gn_file_bitmap_save(name, &tbitmap, &statemachine.driver.phone);
 	if (error != GN_ERR_NONE) {
-		gchar *buf = g_strdup_printf(_("Error saving file\n(error=%d)"), error);
+		gchar *buf = g_strdup_printf(_("Error writing file\n%s"), gn_error_print(error));
 		gtk_label_set_text(GTK_LABEL(errorDialog.text), buf);
 		gtk_widget_show(errorDialog.dialog);
 		g_free(buf);
@@ -1358,16 +1335,16 @@ static void ExportFileSelected(GtkWidget * w, GtkFileSelection * fs)
 	FILE *f;
 	gchar err[255];
 
-	exportDialogData.fileName = gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
+	exportDialogData.fileName = (gchar *) gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
 	gtk_widget_hide(GTK_WIDGET(fs));
 
 	if ((f = fopen(exportDialogData.fileName, "r")) != NULL) {
 		fclose(f);
 		if (dialog.dialog == NULL) {
-			CreateYesNoDialog(&dialog, YesLogoFileExportDialog, CancelDialog,
+			CreateYesNoDialog(&dialog, (GtkSignalFunc) YesLogoFileExportDialog, (GtkSignalFunc) CancelDialog,
 					  GUI_LogosWindow);
 			gtk_window_set_title(GTK_WINDOW(dialog.dialog), _("Overwrite file?"));
-			g_snprintf(err, 255, _("File %s already exist.\nOverwrite?"),
+			g_snprintf(err, 255, _("File %s already exists.\nOverwrite?"),
 				   exportDialogData.fileName);
 			gtk_label_set_text(GTK_LABEL(dialog.text), err);
 		}
@@ -1384,11 +1361,11 @@ void ImportFileSelected(GtkWidget * w, GtkFileSelection * fs)
 	gchar *fileName;
 	FILE *f;
 
-	fileName = gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
+	fileName = (gchar *) gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
 	gtk_widget_hide(GTK_WIDGET(fs));
 
 	if ((f = fopen(fileName, "r")) == NULL) {
-		gchar *buf = g_strdup_printf(_("Can't open file %s for reading !"), fileName);
+		gchar *buf = g_strdup_printf(_("Can't open file %s for reading!\n"), fileName);
 		gtk_label_set_text(GTK_LABEL(errorDialog.text), buf);
 		gtk_widget_show(errorDialog.dialog);
 		g_free(buf);
@@ -1398,7 +1375,7 @@ void ImportFileSelected(GtkWidget * w, GtkFileSelection * fs)
 
 	error = gn_file_bitmap_read(fileName, &tbitmap, &statemachine.driver.phone);
 	if (error != GN_ERR_NONE) {
-		gchar *buf = g_strdup_printf(_("Error reading file\n(error=%d)"), error);
+		gchar *buf = g_strdup_printf(_("Error reading file\n%s"), gn_error_print(error));
 		gtk_label_set_text(GTK_LABEL(errorDialog.text), buf);
 		gtk_widget_show(errorDialog.dialog);
 		g_free(buf);
@@ -1550,8 +1527,8 @@ void GUI_CreateLogosWindow(void)
 	CreateInfoDialog(&infoDialog, GUI_LogosWindow);
 
 	accelGroup = gtk_accel_group_new();
-	gtk_accel_group_attach(accelGroup, GTK_OBJECT(GUI_LogosWindow));
-
+	gtk_window_add_accel_group(GTK_WINDOW(GUI_LogosWindow), accelGroup);
+	
 /* create main vbox */
 	vbox = gtk_vbox_new(FALSE, 1);
 	gtk_container_add(GTK_CONTAINER(GUI_LogosWindow), vbox);
@@ -1565,9 +1542,9 @@ void GUI_CreateLogosWindow(void)
 	gtk_widget_show(menuBar);
 
 /* toolbar */
-	toolBar = gtk_toolbar_new(GTK_ORIENTATION_HORIZONTAL, GTK_TOOLBAR_ICONS);
-	gtk_toolbar_set_button_relief(GTK_TOOLBAR(toolBar), GTK_RELIEF_NORMAL);
+	toolBar = gtk_toolbar_new();
 	gtk_toolbar_set_style(GTK_TOOLBAR(toolBar), GTK_TOOLBAR_ICONS);
+	gtk_toolbar_set_orientation(GTK_TOOLBAR(toolBar), GTK_ORIENTATION_HORIZONTAL);
 
 	gtk_toolbar_append_item(GTK_TOOLBAR(toolBar), NULL, _("Clear logo"), NULL,
 				NewPixmap(New_xpm, GUI_LogosWindow->window,
@@ -1740,9 +1717,9 @@ void GUI_CreateLogosWindow(void)
 	gtk_widget_show(drawingArea);
 
 	/* vertical tool bar */
-	vertToolBar = gtk_toolbar_new(GTK_ORIENTATION_VERTICAL, GTK_TOOLBAR_ICONS);
-	gtk_toolbar_set_button_relief(GTK_TOOLBAR(vertToolBar), GTK_RELIEF_NORMAL);
+	vertToolBar = gtk_toolbar_new();
 	gtk_toolbar_set_style(GTK_TOOLBAR(vertToolBar), GTK_TOOLBAR_ICONS);
+	gtk_toolbar_set_orientation(GTK_TOOLBAR(vertToolBar), GTK_ORIENTATION_VERTICAL);
 
 	buttonBrush = gtk_toolbar_append_element(GTK_TOOLBAR(vertToolBar),
 						 GTK_TOOLBAR_CHILD_RADIOBUTTON, NULL, NULL,
@@ -1847,7 +1824,7 @@ void GUI_ShowLogosWindow(void)
 
 	/* Call to reset Startup logo size */
 	LogoTypeEvent(GUI_LogosWindow);
-	g_print("width: %i, height: %i\n", bitmap.width, bitmap.height);
+	g_print(_("width: %i, height: %i\n"), bitmap.width, bitmap.height);
 	gtk_widget_show(GUI_LogosWindow);
 
 	if (!previewAvailable && showPreviewErrorDialog) {
