@@ -1,6 +1,6 @@
 /*
 
-  $Id: xgnokii_lowlevel.c,v 1.89 2005/06/09 20:38:24 pkot Exp $
+  $Id: xgnokii_lowlevel.c,v 1.92 2006/02/22 15:39:18 dforsi Exp $
   
   X G N O K I I
 
@@ -23,7 +23,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
   Copyright (C) 1999      Pavel Jank ml., Hugh Blemings
-  Copyright (C) 1999-2000 Jn Derfik <ja@mail.upjs.sk>.
+  Copyright (C) 1999-2005 Jan Derfinak
   Copyright (C) 2002-2004 Pawel Kot, BORBELY Zoltan
   Copyright (C) 2002      Markus Plail, Manfred Jonsson, Pavel Machek
   Copyright (C) 2003      Tomi Ollila, Uli Hopp
@@ -161,7 +161,7 @@ static gn_error InitModelInf(void)
 	gdat.model = buf;
 	error = gn_sm_functions(GN_OP_GetModel, &gdat, &statemachine);
 	if (error != GN_ERR_NONE) return error;
-	phoneMonitor.phone.version = g_malloc(sizeof(gdat.model));
+	phoneMonitor.phone.version = g_strdup(gdat.model);
 	phoneMonitor.phone.model = gn_model_get(gdat.model);
 
 	if (phoneMonitor.phone.model == NULL)
@@ -172,9 +172,6 @@ static gn_error InitModelInf(void)
 	gdat.model = NULL;
 	error = gn_sm_functions(GN_OP_GetRevision, &gdat, &statemachine);
 	if (error != GN_ERR_NONE) return error;
-	phoneMonitor.phone.version = g_malloc(sizeof(gdat.revision));
-	phoneMonitor.phone.revision = g_malloc(sizeof(gdat.revision));
-	phoneMonitor.phone.version = g_strdup(gdat.revision);
 	phoneMonitor.phone.revision = g_strdup(gdat.revision);
 
 	gdat.revision = NULL;
@@ -182,7 +179,6 @@ static gn_error InitModelInf(void)
 	gdat.imei = buf;
 	error = gn_sm_functions(GN_OP_GetImei, &gdat, &statemachine);
 	if (error != GN_ERR_NONE) return error;
-	phoneMonitor.phone.imei = g_malloc(sizeof(gdat.imei));
 	phoneMonitor.phone.imei = g_strdup(gdat.imei);
 
 	for (i = 0; i < GN_SMS_FOLDER_MAX_NUMBER; i++) {
@@ -223,7 +219,7 @@ static gn_error fbusinit(bool enable_monitoring)
 	if (aux && !strcmp(aux, "yes")) {
 		lockfile = gn_device_lock(xgnokiiConfig.port);
 		if (lockfile == NULL) {
-			fprintf(stderr, _("Lock file error. Exiting\n"));
+			fprintf(stderr, _("Lock file error. Exiting.\n"));
 			MainExit();
 		}
 	}
@@ -240,7 +236,7 @@ static gn_error fbusinit(bool enable_monitoring)
 	gn_log_xdebug("fbusinit: error %d\n", error);
 
 	if (error != GN_ERR_NONE) {
-		g_print(_("GSM/FBUS init failed!\n"));
+		g_print(_("GSM/FBUS init failed! (Unknown model?). Quitting.\n"));
 		/* FIXME: should popup some message... */
 		return (error);
 	}
