@@ -1,6 +1,6 @@
 /*
 
-  $Id: xgnokii_sms.c,v 1.60 2005/04/28 20:35:59 pkot Exp $
+  $Id: xgnokii_sms.c,v 1.64 2006/01/15 15:13:27 dforsi Exp $
 
   X G N O K I I
 
@@ -23,7 +23,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
   Copyright (C) 1999 Pavel Jank ml., Hugh Blemings
-  Copyright (C) 1999-2002 Jn Derfik <ja@mail.upjs.sk>.
+  Copyright (C) 1999-2005 Jan Derfinak
   Copyright (C) 2001-2003 Pawel Kot
   Copyright (C) 2002-2003 BORBELY Zoltan
   Copyright (C) 2002      Markus Plail
@@ -357,18 +357,18 @@ static void InsertFolderElement(gpointer d, gpointer userData)
 
 		if (dt) {
 			if (dt->timezone)
-				row[1] = g_strdup_printf("%02d/%02d/%04d %02d:%02d:%02d %c%02d00",
+				row[1] = g_strdup_printf(_("%02d/%02d/%04d %02d:%02d:%02d %c%02d00"),
 							 dt->day, dt->month, dt->year,
 							 dt->hour, dt->minute, dt->second,
 							 dt->timezone > 0 ? '+' : '-',
 							 abs(dt->timezone));
 			else
-				row[1] = g_strdup_printf("%02d/%02d/%04d %02d:%02d:%02d",
+				row[1] = g_strdup_printf(_("%02d/%02d/%04d %02d:%02d:%02d"),
 							 dt->day, dt->month, dt->year,
 							 dt->hour, dt->minute, dt->second);
 		} else {
 			row[1] =
-			    g_strdup_printf("%02d/%02d/%04d %02d:%02d:%02d", 01, 01, 0001, 01, 01,
+			    g_strdup_printf(_("%02d/%02d/%04d %02d:%02d:%02d"), 01, 01, 0001, 01, 01,
 					    01);
 		}
 
@@ -376,7 +376,7 @@ static void InsertFolderElement(gpointer d, gpointer userData)
 		if (row[2] == NULL)
 			row[2] = data->remote.number;
 		if ((data->type == GN_SMS_MT_Picture) || (data->type == GN_SMS_MT_PictureTemplate))
-			row[3] = g_strdup_printf("Picture Message: %s", data->user_data[1].u.text);
+			row[3] = g_strdup_printf(_("Picture Message: %s"), data->user_data[1].u.text);
 		else
 			row[3] = data->user_data[0].u.text;
 
@@ -721,7 +721,7 @@ static void SaveToMailbox(gchar *mailbox_name)
 
 static void OKSaveSMStoMailbox(GtkWidget * widget, gpointer data)
 {
-  mailbox_name = gtk_file_selection_get_filename(GTK_FILE_SELECTION(data));
+  mailbox_name = (gchar *) gtk_file_selection_get_filename(GTK_FILE_SELECTION(data));
   SaveToMailbox(mailbox_name);
   gtk_widget_hide(GTK_WIDGET(data));
 }
@@ -762,7 +762,7 @@ create_SaveSMStoMailbox (void)
   SaveSMStoMailbox = gtk_file_selection_new (_("Choose Mailbox File"));
   gtk_object_set_data (GTK_OBJECT (SaveSMStoMailbox), "SaveSMStoMailbox", SaveSMStoMailbox);
   gtk_container_set_border_width (GTK_CONTAINER (SaveSMStoMailbox), 10);
-  GTK_WINDOW (SaveSMStoMailbox)->type = GTK_WINDOW_DIALOG;
+  GTK_WINDOW (SaveSMStoMailbox)->type = GTK_WINDOW_TOPLEVEL;
 
   ok_button1 = GTK_FILE_SELECTION (SaveSMStoMailbox)->ok_button;
   gtk_object_set_data (GTK_OBJECT (SaveSMStoMailbox), "ok_button1", ok_button1);
@@ -810,7 +810,7 @@ static inline void RefreshSMSStatus(void)
 static inline gint RefreshSMSLength(GtkWidget * widget, GdkEventKey * event, gpointer callback_data)
 {
 	RefreshSMSStatus();
-	if (GTK_EDITABLE(widget)->editable == FALSE)
+	if (gtk_editable_get_editable (GTK_EDITABLE(widget)) == FALSE)
 		return (FALSE);
 	if (event->keyval == GDK_BackSpace || event->keyval == GDK_Clear ||
 	    event->keyval == GDK_Insert || event->keyval == GDK_Delete ||
@@ -875,7 +875,7 @@ static inline void InitAddressLine(gpointer d, gpointer userData)
 #ifdef XDEBUG
 static inline void PrintAddressLine(gpointer d, gpointer userData)
 {
-	g_print("Name: %s\nNumber: %s\nUsed: %d\n",
+	g_print(_("Name: %s\nNumber: %s\nUsed: %d\n"),
 		((AddressPar *) d)->name, ((AddressPar *) d)->number, ((AddressPar *) d)->used);
 }
 #endif
@@ -1078,13 +1078,13 @@ static gint Sendsmscore(gn_sms * sms)
 	g_free(m);
 
 	if (error != GN_ERR_NONE) {
-		gchar *buf = g_strdup_printf(_("SMS send to %s failed\n(error=%d)"),
-					     sms->remote.number, error);
+		gchar *buf = g_strdup_printf(_("Error sending SMS to %s\n%s"),
+					     sms->remote.number, gn_error_print(error));
 		gtk_label_set_text(GTK_LABEL(errorDialog.text), buf);
 		gtk_widget_show(errorDialog.dialog);
 		g_free(buf);
 	} else
-		g_print("Message sent to: %s\n", sms->remote.number);
+		g_print(_("Message sent to: %s\n"), sms->remote.number);
 
 	return (error);
 }
@@ -1222,7 +1222,7 @@ static void DoSendSMS(void)
 			strncpy(sms.user_data[0].u.text, text, GN_SMS_MAX_LENGTH + 1);
 			sms.user_data[0].u.text[GN_SMS_MAX_LENGTH] = '\0';
 
-			buf = g_strdup_printf(_("Sending SMS to %s ...\n"), sms.remote.number);
+			buf = g_strdup_printf(_("Sending SMS to %s (%d/%d) ...\n"), sms.remote.number, 1, 1);
 			gtk_label_set_text(GTK_LABEL(infoDialog.text), buf);
 			gtk_widget_show_now(infoDialog.dialog);
 			g_free(buf);
@@ -1305,7 +1305,7 @@ static void CreateSMSSendWindow(void)
 
 	gtk_item_factory_create_items(item_factory, nmenu_items, send_menu_items, NULL);
 
-	gtk_accel_group_attach(accel_group, GTK_OBJECT(sendSMS.SMSSendWindow));
+	gtk_window_add_accel_group(GTK_WINDOW(sendSMS.SMSSendWindow), accel_group);
 
 	/* Finally, return the actual menu bar created by the item factory. */
 	menubar = gtk_item_factory_get_widget(item_factory, "<main>");
@@ -1320,8 +1320,9 @@ static void CreateSMSSendWindow(void)
 
 	/* Create the toolbar */
 
-	toolbar = gtk_toolbar_new(GTK_ORIENTATION_HORIZONTAL, GTK_TOOLBAR_ICONS);
-	gtk_toolbar_set_button_relief(GTK_TOOLBAR(toolbar), GTK_RELIEF_NORMAL);
+	toolbar = gtk_toolbar_new();
+	gtk_toolbar_set_style(GTK_TOOLBAR(toolbar), GTK_TOOLBAR_ICONS);
+	gtk_toolbar_set_orientation(GTK_TOOLBAR(toolbar), GTK_ORIENTATION_HORIZONTAL);
 
 	gtk_toolbar_append_item(GTK_TOOLBAR(toolbar), NULL, _("Send message"), NULL,
 				NewPixmap(SendSMS_xpm, GUI_SMSWindow->window,
@@ -1644,7 +1645,7 @@ static GtkItemFactoryEntry menu_items[] = {
 	{NULL, NULL, NULL, 0, "<Separator>"},
 	{NULL, "<control>W", CloseSMS, 0, NULL},
 	{NULL, NULL, NULL, 0, "<Branch>"},
-	{NULL, "<control>A", ActivateSMS, 0, NULL},
+	{NULL, "<control>A", ActivateSMS, 0, "<CheckItem>"},
 	{NULL, "<control>N", NewSMS, 0, NULL},
 	{NULL, "<control>F", ForwardSMS, 0, NULL},
 	{NULL, "<control>R", ReplySMS, 0, NULL},
@@ -1668,7 +1669,7 @@ static void InitMainMenu(void)
 	menu_items[i++].path = g_strdup(_("/File/Sep1"));
 	menu_items[i++].path = g_strdup(_("/File/_Close"));
 	menu_items[i++].path = g_strdup(_("/_Messages"));
-	menu_items[i++].path = g_strdup(_("/_Messages/(De)_Activate SMS reading"));
+	menu_items[i++].path = g_strdup(_("/_Messages/_Activate SMS reading"));
 	menu_items[i++].path = g_strdup(_("/_Messages/_New"));
 	menu_items[i++].path = g_strdup(_("/_Messages/_Forward"));
 	menu_items[i++].path = g_strdup(_("/_Messages/_Reply"));
@@ -1714,7 +1715,7 @@ void GUI_CreateSMSWindow(void)
 
 	gtk_item_factory_create_items(item_factory, nmenu_items, menu_items, NULL);
 
-	gtk_accel_group_attach(accel_group, GTK_OBJECT(GUI_SMSWindow));
+	gtk_window_add_accel_group(GTK_WINDOW(GUI_SMSWindow), accel_group);
 
 	/* Finally, return the actual menu bar created by the item factory. */
 	menubar = gtk_item_factory_get_widget(item_factory, "<main>");
@@ -1728,8 +1729,9 @@ void GUI_CreateSMSWindow(void)
 	gtk_widget_show(menubar);
 
 	/* Create the toolbar */
-	toolbar = gtk_toolbar_new(GTK_ORIENTATION_HORIZONTAL, GTK_TOOLBAR_ICONS);
-	gtk_toolbar_set_button_relief(GTK_TOOLBAR(toolbar), GTK_RELIEF_NORMAL);
+	toolbar = gtk_toolbar_new();
+	gtk_toolbar_set_style(GTK_TOOLBAR(toolbar), GTK_TOOLBAR_ICONS);
+	gtk_toolbar_set_orientation(GTK_TOOLBAR(toolbar), GTK_ORIENTATION_HORIZONTAL);
 
 	gtk_toolbar_append_item(GTK_TOOLBAR(toolbar), NULL, _("New message"), NULL,
 				NewPixmap(Edit_xpm, GUI_SMSWindow->window,
@@ -1760,14 +1762,14 @@ void GUI_CreateSMSWindow(void)
 	gtk_widget_show(toolbar);
 
 	vpaned = gtk_vpaned_new();
-	gtk_paned_set_handle_size(GTK_PANED(vpaned), 10);
-	gtk_paned_set_gutter_size(GTK_PANED(vpaned), 15);
+//	gtk_paned_set_handle_size(GTK_PANED(vpaned), 10);
+//	gtk_paned_set_gutter_size(GTK_PANED(vpaned), 15);
 	gtk_box_pack_end(GTK_BOX(main_vbox), vpaned, TRUE, TRUE, 0);
 	gtk_widget_show(vpaned);
 
 	hpaned = gtk_hpaned_new();
-	gtk_paned_set_handle_size(GTK_PANED(hpaned), 8);
-	gtk_paned_set_gutter_size(GTK_PANED(hpaned), 10);
+//	gtk_paned_set_handle_size(GTK_PANED(hpaned), 8);
+//	gtk_paned_set_gutter_size(GTK_PANED(hpaned), 10);
 	gtk_paned_add1(GTK_PANED(vpaned), hpaned);
 	gtk_widget_show(hpaned);
 
