@@ -1,6 +1,6 @@
 /*
 
-  $Id: xgnokii_speed.c,v 1.17 2005/04/24 20:57:37 pkot Exp $
+  $Id: xgnokii_speed.c,v 1.20 2006/01/15 15:13:27 dforsi Exp $
 
   X G N O K I I
 
@@ -23,7 +23,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
   Copyright (C) 1999 Pavel Jank ml., Hugh Blemings
-  & Jn Derfik <ja@mail.upjs.sk>.
+  & 1999-2005 Jan Derfinak
   Copyright (C) 2002-2003 Pawel Kot
   Copyright (C) 2002      BORBELY Zoltan, Markus Plail
 
@@ -195,13 +195,13 @@ static void ReadSpeedDial(void)
 
 	for (i = 2; i < 10; i++) {
 		if ((d = (D_SpeedDial *) g_malloc(sizeof(D_SpeedDial))) == NULL) {
-			g_print(_("Cannot allocate memory!"));
+			g_print(_("Cannot allocate memory!\n"));
 			return;
 		}
 		memset(d, 0, sizeof(D_SpeedDial));
 		d->entry.number = i;
 		if ((e = (PhoneEvent *) g_malloc(sizeof(PhoneEvent))) == NULL) {
-			g_print(_("Cannot allocate memory!"));
+			g_print(_("Cannot allocate memory!\n"));
 			g_free(d);
 			return;
 		}
@@ -212,7 +212,7 @@ static void ReadSpeedDial(void)
 		pthread_cond_wait(&speedDialCond, &speedDialMutex);
 		pthread_mutex_unlock(&speedDialMutex);
 		if (d->status != GN_ERR_NONE) {
-			g_print("Cannot read speed dial key %d!\n", i);
+			g_print(_("Cannot read speed dial key %d!\n"), i);
 			*buf = i + '0';
 			row[0] = buf;
 			row[1] = '\0';
@@ -261,7 +261,7 @@ static void SaveSpeedDial(void)
 				if (d->entry.location == 0)
 					continue;
 				if ((e = (PhoneEvent *) g_malloc(sizeof(PhoneEvent))) == NULL) {
-					g_print(_("Cannot allocate memory!"));
+					g_print(_("Cannot allocate memory!\n"));
 					return;
 				}
 
@@ -325,11 +325,11 @@ static void OkImportDialog(GtkWidget * w, GtkFileSelection * fs)
 	gint location;
 	register gint i, row_i = 0;
 
-	fileName = gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
+	fileName = (gchar *) gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
 	gtk_widget_hide(GTK_WIDGET(fs));
 
 	if ((f = fopen(fileName, "r")) == NULL) {
-		g_snprintf(buf, IO_BUF_LEN, _("Can't open file %s for reading!"), fileName);
+		g_snprintf(buf, IO_BUF_LEN, _("Can't open file %s for reading!\n"), fileName);
 		gtk_label_set_text(GTK_LABEL(errorDialog.text), buf);
 		gtk_widget_show(errorDialog.dialog);
 		return;
@@ -400,7 +400,7 @@ static void ImportSpeedDial(void)
 	static GtkWidget *fileDialog = NULL;
 
 	if (fileDialog == NULL) {
-		fileDialog = gtk_file_selection_new(_("Import"));
+		fileDialog = gtk_file_selection_new(_("Import from file"));
 		gtk_signal_connect(GTK_OBJECT(fileDialog), "delete_event",
 				   GTK_SIGNAL_FUNC(DeleteEvent), NULL);
 		gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(fileDialog)->ok_button),
@@ -422,7 +422,7 @@ static void ExportSpeedDialMain(gchar * name)
 	register gint i;
 
 	if ((f = fopen(name, "w")) == NULL) {
-		g_snprintf(buf, IO_BUF_LEN, _("Can't open file %s for writing!"), name);
+		g_snprintf(buf, IO_BUF_LEN, _("Can't open file %s for writing!\n"), name);
 		gtk_label_set_text(GTK_LABEL(errorDialog.text), buf);
 		gtk_widget_show(errorDialog.dialog);
 		return;
@@ -454,16 +454,16 @@ static void OkExportDialog(GtkWidget * w, GtkFileSelection * fs)
 	gchar err[255];
 
 
-	exportDialogData.fileName = gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
+	exportDialogData.fileName = (gchar *) gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
 	gtk_widget_hide(GTK_WIDGET(fs));
 
 	if ((f = fopen(exportDialogData.fileName, "r")) != NULL) {
 		fclose(f);
 		if (dialog.dialog == NULL) {
-			CreateYesNoDialog(&dialog, YesExportDialog, CancelDialog,
+			CreateYesNoDialog(&dialog, (GtkSignalFunc) YesExportDialog, (GtkSignalFunc) CancelDialog,
 					  GUI_SpeedDialWindow);
 			gtk_window_set_title(GTK_WINDOW(dialog.dialog), _("Overwrite file?"));
-			g_snprintf(err, 255, _("File %s already exist.\nOverwrite?"),
+			g_snprintf(err, 255, _("File %s already exists.\nOverwrite?"),
 				   exportDialogData.fileName);
 			gtk_label_set_text(GTK_LABEL(dialog.text), err);
 		}
@@ -479,7 +479,7 @@ static void ExportSpeedDial(void)
 
 	if (speedDialInitialized) {
 		if (fileDialog == NULL) {
-			fileDialog = gtk_file_selection_new(_("Export"));
+			fileDialog = gtk_file_selection_new(_("Export to file"));
 			gtk_signal_connect(GTK_OBJECT(fileDialog), "delete_event",
 					   GTK_SIGNAL_FUNC(DeleteEvent), NULL);
 			gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(fileDialog)->ok_button),
@@ -567,7 +567,7 @@ void GUI_CreateSpeedDialWindow(void)
 
 	gtk_item_factory_create_items(item_factory, nmenu_items, menu_items, NULL);
 
-	gtk_accel_group_attach(accel_group, GTK_OBJECT(GUI_SpeedDialWindow));
+	gtk_window_add_accel_group(GTK_WINDOW(GUI_SpeedDialWindow), accel_group);
 
 	/* Finally, return the actual menu bar created by the item factory. */
 	menubar = gtk_item_factory_get_widget(item_factory, "<main>");
@@ -582,8 +582,9 @@ void GUI_CreateSpeedDialWindow(void)
 
 	/* Create the toolbar */
 
-	toolbar = gtk_toolbar_new(GTK_ORIENTATION_HORIZONTAL, GTK_TOOLBAR_ICONS);
-	gtk_toolbar_set_button_relief(GTK_TOOLBAR(toolbar), GTK_RELIEF_NORMAL);
+	toolbar = gtk_toolbar_new();
+	gtk_toolbar_set_style(GTK_TOOLBAR(toolbar), GTK_TOOLBAR_ICONS);
+	gtk_toolbar_set_orientation(GTK_TOOLBAR(toolbar), GTK_ORIENTATION_HORIZONTAL);
 
 	gtk_toolbar_append_item(GTK_TOOLBAR(toolbar), NULL, _("Read from phone"), NULL,
 				NewPixmap(Read_xpm, GUI_SpeedDialWindow->window,
